<template>
    <el-dialog
        :visible.sync="driverSelectFormVisible"
        append-to-body
        :close-on-click-modal="false"
        width="70%">
    <div class="app-container">
        <div class="filter-container">
            <div class="carrier_search">
                <span>按隶属承运人查：</span>
                <el-input v-model="listQuery.filter.companyname" class="carrier_search_input"></el-input>
            </div>
            <div class="carrier_search">
                <span>按姓名查：</span>
                <el-input v-model="listQuery.filter.name" class="carrier_search_input"></el-input>
            </div>
            <el-button  style="margin-left: 10px;" type="primary"  @click="searchData()">查询</el-button>
        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="carrierList"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="单位名称" prop="belongname" align="center">
                </el-table-column>
                <el-table-column label="类型" prop="type" align="center">
                </el-table-column>
                <el-table-column label="姓名" prop="name" align="center">
                </el-table-column>
                <el-table-column label="身份证" prop="identify" align="center">
                </el-table-column>
                <el-table-column label="资格证" prop="certificate" align="center">
                </el-table-column>
                <el-table-column label="证件有效期" prop="validtime" align="center">
                </el-table-column>
                <el-table-column label="操作" align="center" width="180" class-name="small-padding fixed-width">
                    <template slot-scope="scope">
                        <el-button type="text" @click="giveDriver(scope.row)">选择</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
            <br>
        </div>
    </div>
    </el-dialog>
</template>

<script>

import { computePageCount } from '@/utils'
import { getDriverData } from "@/api/driver";

export default {
    name: "carrier",
    data(){
        return{
            tableKey:0,
            listLoading:false,
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            listQuery:{
                filter:{
                    name:'',
                    belongname:'',
                },
                pageIndex:1,
                pageSize:10,
            },
            searchContent:'',
            carrierList:[],
            driverSelectFormVisible:false,
        }
    },
    created(){
        this.getDriverData()
    },
    methods:{
        selectDriver(){
            this.driverSelectFormVisible = true
        },
        async getDriverData(){
            this.listLoading = true
            let res = await getDriverData(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.carrierList = res.data.result.records
            }
            this.listLoading = false
        },
        giveDriver(row){
            this.$emit('getinfo',row)
            this.driverSelectFormVisible = false
        },
        searchData(){
            this.getDriverData()
        },
        handleSizeChange: function(val) {
            this.pageSize = val
            this.currentPage = 1
            this.getDriverData()
        },
        handleCurrentChange: function(val) {
            this.currentPage = val
            this.getDriverData()
        },
    }
}
</script>

<style scoped>
.carrier_search{
    display: inline-block;
}
.carrier_search_input{
    width:200px;
}
/deep/ .table_content{
    padding:0px;
}
</style>
